@@ -3,10 +3,10 @@ Controller of the whole program
 """
 
 from . import UMRLogging
-from . import UMRDriver
+from . import UMRConfig
 from . import UMRDispatcher
-from . import UMRCommand
-
+from . import UMRDriver
+from . import UMRExtension
 import asyncio
 
 from time import sleep
@@ -17,16 +17,24 @@ class UMRManager:
     @staticmethod
     def run():
         try:
+            # init logging to file
+            UMRLogging.post_init()
+
             # init message dispatcher
             UMRDispatcher.init_dispatcher()
 
             # init driver and other extensions
-            from . import UMRExtension
-            UMRExtension.load_extensions()
+            UMRConfig.load_extensions()
+
+            # reload config
+            UMRConfig.reload_config()
 
             # init drivers for different platform
             asyncio.run(UMRDriver.init_drivers())
 
+            # init extensions after driver is available
+            asyncio.run(UMRExtension.post_init())
+
             # block main thread
             for i in UMRDriver.threads:
                 i.join()
